@@ -298,14 +298,14 @@ _shishi_enckdcreppart_input (Shishi * handle,
   if (*enckdcreppart == NULL)
     {
       shishi_error_printf (handle, "Could not DER decode Encasreppart: %s",
-			   shishi_strerror_details (handle));
+			   shishi_error (handle));
 
       *enckdcreppart = shishi_der2asn1_enctgsreppart (handle, der, derlen);
       if (*enckdcreppart == NULL)
 	{
 	  shishi_error_printf (handle,
 			       "Could not DER decode Enctgsreppart: %s",
-			       shishi_strerror_details (handle));
+			       shishi_error (handle));
 
 	  *enckdcreppart =
 	    shishi_der2asn1_enckdcreppart (handle, der, derlen);
@@ -313,7 +313,7 @@ _shishi_enckdcreppart_input (Shishi * handle,
 	    {
 	      shishi_error_printf (handle,
 				   "Could not DER decode Enckdcreppart: %s",
-				   shishi_strerror_details (handle));
+				   shishi_error (handle));
 	      return !SHISHI_OK;
 	    }
 	}
@@ -439,14 +439,14 @@ _shishi_kdcrep_input (Shishi * handle, FILE * fh, Shishi_asn1 * asrep,
       if (*asrep == NULL)
 	{
 	  printf ("Could not DER decode KDC-REP: %s\n",
-		  shishi_strerror_details (handle));
+		  shishi_error (handle));
 	  printf ("Parsing AS/TGS-REP as KDC-REP (bug work around)\n");
 
 	  *asrep = shishi_der2asn1_kdcrep (handle, der, derlen);
 	  if (*asrep == NULL)
 	    {
 	      fprintf (stderr, "Could not DER decode KDC-REP: %s\n",
-		       shishi_strerror_details (handle));
+		       shishi_error (handle));
 	      return !SHISHI_OK;
 	    }
 
@@ -495,7 +495,7 @@ _shishi_apreq_input (Shishi * handle, FILE * fh, Shishi_asn1 * apreq,
   *apreq = shishi_der2asn1_apreq (handle, der, derlen);
   if (*apreq == NULL)
     {
-      printf ("bad magic %s\n", shishi_strerror_details (handle));
+      printf ("bad magic %s\n", shishi_error (handle));
       shishi_error_printf (handle, "Could not DER decode AP-REQ\n");
 
       return !SHISHI_OK;
@@ -542,7 +542,7 @@ _shishi_aprep_input (Shishi * handle, FILE * fh, Shishi_asn1 * aprep,
   *aprep = shishi_der2asn1_aprep (handle, der, derlen);
   if (*aprep == NULL)
     {
-      printf ("bad magic %s\n", shishi_strerror_details (handle));
+      printf ("bad magic %s\n", shishi_error (handle));
       shishi_error_printf (handle, "Could not DER decode AP-REP\n");
 
       return !SHISHI_OK;
@@ -591,7 +591,7 @@ _shishi_encapreppart_input (Shishi * handle, FILE * fh,
   *encapreppart = shishi_der2asn1_encapreppart (handle, der, derlen);
   if (*encapreppart == NULL)
     {
-      printf ("bad magic %s\n", shishi_strerror_details (handle));
+      printf ("bad magic %s\n", shishi_error (handle));
       shishi_error_printf (handle, "Could not DER decode EncAPRepPart\n");
 
       return !SHISHI_OK;
@@ -639,7 +639,7 @@ _shishi_authenticator_input (Shishi * handle,
   *authenticator = shishi_der2asn1_authenticator (handle, der, derlen);
   if (*authenticator == NULL)
     {
-      printf ("bad magic %s\n", shishi_strerror_details (handle));
+      printf ("bad magic %s\n", shishi_error (handle));
       shishi_error_printf (handle, "Could not DER decode AP-REQ\n");
 
       return !SHISHI_OK;
@@ -687,7 +687,7 @@ _shishi_krberror_input (Shishi * handle,
   *krberror = shishi_der2asn1_krberror (handle, der, derlen);
   if (*krberror == NULL)
     {
-      printf ("bad magic %s\n", shishi_strerror_details (handle));
+      printf ("bad magic %s\n", shishi_error (handle));
       shishi_error_printf (handle, "Could not DER decode AP-REQ\n");
 
       return !SHISHI_OK;
@@ -734,7 +734,7 @@ _shishi_safe_input (Shishi * handle, FILE * fh, Shishi_asn1 * safe, int type)
   *safe = shishi_der2asn1_krbsafe (handle, der, derlen);
   if (*safe == NULL)
     {
-      printf ("bad magic %s\n", shishi_strerror_details (handle));
+      printf ("bad magic %s\n", shishi_error (handle));
       shishi_error_printf (handle, "Could not DER decode KRB-SAFE\n");
 
       return !SHISHI_OK;
@@ -743,6 +743,53 @@ _shishi_safe_input (Shishi * handle, FILE * fh, Shishi_asn1 * safe, int type)
   return SHISHI_OK;
 }
 
+int
+_shishi_priv_input (Shishi * handle, FILE * fh, Shishi_asn1 * priv, int type)
+{
+  char der[BUFSIZ];
+  size_t derlen;
+  char b64der[BUFSIZ];
+  size_t b64len = 0;
+  int res;
+
+  if (type == 0)
+    {
+      b64len = sizeof (b64der);
+      res = _shishi_read_armored_data (handle, fh, b64der, b64len,
+				       "KRB-PRIV");
+      if (res != SHISHI_OK)
+	{
+	  shishi_error_printf (handle, "armor data read fail\n");
+	  return res;
+	}
+
+      derlen = base64_from (&der[0], b64der);
+    }
+  else
+    {
+      derlen = fread (der, sizeof (der[0]),
+		      sizeof (der) / sizeof (der[0]), fh);
+      if (derlen <= 0 || !feof (fh) || ferror (fh))
+	{
+	  shishi_error_printf (handle,
+			       "Error reading from file (got %d bytes)...",
+			       derlen);
+	  return !SHISHI_OK;
+	}
+    }
+
+  *priv = shishi_der2asn1_priv (handle, der, derlen);
+  if (*priv == NULL)
+    {
+      printf ("bad magic %s\n", shishi_error (handle));
+      shishi_error_printf (handle, "Could not DER decode KRB-PRIV\n");
+
+      return !SHISHI_OK;
+    }
+
+  return SHISHI_OK;
+}
+
 int
 shishi_key_parse (Shishi * handle, FILE * fh, Shishi_key ** key)
 {
@@ -858,7 +905,7 @@ shishi_key_print (Shishi * handle, FILE * fh, Shishi_key * key)
   size_t i;
 
   base64_to (b64key, shishi_key_value (key),
-		    shishi_key_length (key), sizeof (b64key));
+	     shishi_key_length (key), sizeof (b64key));
 
   fprintf (fh, HEADERBEG "\n", "KEY");
 
