@@ -78,7 +78,6 @@ shishi_crc (Shishi * handle, const char *in, size_t inlen, char *out[4])
 {
   gcry_md_hd_t hd;
   gpg_error_t err;
-  char T[4];
   char *p;
 
   err = gcry_md_open (&hd, GCRY_MD_CRC32_RFC1510, 0);
@@ -134,7 +133,7 @@ shishi_md4 (Shishi * handle, const char *in, size_t inlen, char *out[16])
       return SHISHI_CRYPTO_INTERNAL_ERROR;
     }
 
-  *out = xmemdup (p, gcry_md_get_algo_dlen (GCRY_MD_MD4));
+  *out = xclone (p, gcry_md_get_algo_dlen (GCRY_MD_MD4));
 
   gcry_md_close (hd);
 
@@ -165,7 +164,7 @@ shishi_md5 (Shishi * handle, const char *in, size_t inlen, char *out[16])
       return SHISHI_CRYPTO_INTERNAL_ERROR;
     }
 
-  *out = xmemdup (p, gcry_md_get_algo_dlen (GCRY_MD_MD5));
+  *out = xclone (p, gcry_md_get_algo_dlen (GCRY_MD_MD5));
 
   gcry_md_close (hd);
 
@@ -207,7 +206,7 @@ shishi_hmac_md5 (Shishi * handle,
       return SHISHI_CRYPTO_INTERNAL_ERROR;
     }
 
-  *outhash = xmemdup (hash, hlen);
+  *outhash = xclone (hash, hlen);
 
   gcry_md_close (mdh);
 
@@ -249,7 +248,7 @@ shishi_hmac_sha1 (Shishi * handle,
       return SHISHI_CRYPTO_INTERNAL_ERROR;
     }
 
-  *outhash = xmemdup (hash, hlen);
+  *outhash = xclone (hash, hlen);
 
   gcry_md_close (mdh);
 
