@@ -57,7 +57,8 @@ shishi_tkts_default_file_guess (void)
  * @handle: Shishi library handle create by shishi_init().
  *
  * Return value: Returns the default ticket set filename used in the
- * library.  (Not a copy of it, so don't modify or deallocate it.)
+ * library.  The string is not a copy, so don't modify or deallocate
+ * it.
  **/
 const char *
 shishi_tkts_default_file (Shishi * handle)
@@ -895,6 +896,7 @@ shishi_tkts_get_tgt (Shishi_tkts * tkts, Shishi_tkts_hint * hint)
   tgt = shishi_tkts_find (tkts, &lochint);
 
   free (lochint.server);
+  lochint.server = NULL;
 
   if (tgt)
     return tgt;
@@ -905,7 +907,7 @@ shishi_tkts_get_tgt (Shishi_tkts * tkts, Shishi_tkts_hint * hint)
   if (rc == SHISHI_OK)
     rc = shishi_as_req_build (as);
   if (rc == SHISHI_OK)
-    rc = shishi_as_sendrecv (as);
+    rc = shishi_as_sendrecv_hint (as, &lochint);
   if (rc == SHISHI_OK)
     rc = shishi_as_rep_process (as, NULL, hint->passwd);
   if (rc != SHISHI_OK)
@@ -971,7 +973,7 @@ shishi_tkts_get_tgs (Shishi_tkts * tkts,
   if (rc == SHISHI_OK)
     rc = shishi_tgs_req_build (tgs);
   if (rc == SHISHI_OK)
-    rc = shishi_tgs_sendrecv (tgs);
+    rc = shishi_tgs_sendrecv_hint (tgs, hint);
   if (rc == SHISHI_OK)
     rc = shishi_tgs_rep_process (tgs);
   if (rc != SHISHI_OK)
